//=============================================================================
//  MuseScore
//  Linux Music Score Editor
//  $Id:$
//
//  Creates a harp pedal diagram at a selection, or at the beginning of the score
//  if no selection is made.
//
//  Requires: harp.ui, Harpfont.ttf. The latter must be installed for this plugin to work.
//
//  Copyright (C)2012 Ian Boswell
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License version 2.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//=============================================================================

//
// This is ECMAScript code (ECMA-262 aka "Java Script")
//

var form;

function init()
      {};   //Called at MuseScore startup

function run()
      {     //Called when the user activates the plugin
      var loader = new QUiLoader(null);
      var file = new QFile(pluginPath + "/harp.ui");
      file.open(QIODevice.OpenMode(QIODevice.ReadOnly, QIODevice.Text));
      form = loader.load(file, null);
      form.buttonBox.accepted.connect(okay);
      form.show();
      };

function okay()
      {     //Called when user hits OK button in the QT dialog box
      var cursor = new Cursor(curScore);
      cursor.goToSelectionStart();
      if (cursor.eos())       // If there is no selection, cursor goes to end of score
            {
            cursor.rewind();  // Default option in case no selection is made
            }

      var diagram = new Text(curScore);
      diagram.defaultFont = new QFont("Harpfont", form.fontSize.value);
      diagram.text = getValue(form.D) + getValue(form.C) + getValue(form.B) +
            "d" + getValue(form.E) + getValue(form.F) + getValue(form.G) +
            getValue(form.A);
      cursor.putStaffText(diagram);
      diagram.xOffset = -1;
      diagram.yOffset = -5;

      curScore.endUndo();     //required for diagram to display immediately
      formProc.close();
      };

function getValue(vS)
      {     //Takes valueSlider object as input, returns letters which are displayed
      switch(vS.value)  //through Harpfont, creating a harp pedal diagram
            {
            case 0:
                  return "c";
            case 1:
                  return "a";
            case 2:
                  return "b";
            };
      };

var mscorePlugin = {
      menu: 'Plugins.Harp Pedal Diagram',
      init: init,
      run: run,
      };

mscorePlugin;
